@@ -116,14 +116,14 @@ class OrderController
         $days = [];
         foreach ($orders as $singleOrder) {
 
-
             if ($_GET['location'] === strtolower(self::getShippingDetails($singleOrder)['Pickup Location'])) {
                 $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
                 $pickupDate = strtotime($pickupDate);
                 $newDate = date('l jS \of F', $pickupDate);
 
                 $order = new Order($singleOrder);
-                if ($order->getOrderStatus() != "6" && $order->getOrderStatus() != "7") {
+
+                if ($order->getOrderStatus() != "6" && $order->getOrderStatus() != "7" && $order->getOrderStatus() != "8") {
 
                     if (!isset($days[$pickupDate])) {
                         $days[$pickupDate] = [
@@ -141,6 +141,10 @@ class OrderController
         return json_encode($days);
     }
 
+    /**
+     * @param $order
+     * @return array
+     */
     public static function getShippingDetails($order)
     {
 
@@ -193,40 +197,72 @@ class OrderController
         return json_encode($days);
     }
 
-    public static function orderDataForPrint($orders, $location, $date)
+    public static function searchOrders($searchTerm)
     {
+        $isPostcode = self::checkPostcode($searchTerm);
 
-        $orderData = [];
-        foreach ($orders as $singleOrder) {
-            $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
+        if ($isPostcode === true) {
+            $orders = wc_get_orders([
+                'billing_postcode' => $searchTerm,
+            ]);
+        } else {
+            $firstNameArgs = [
+                'limit' => -1,
+                'billing_first_name' => $searchTerm,
+            ];
+            $firstNameQuery = new \WC_Order_Query($firstNameArgs);
+            $firstNameOrders = $firstNameQuery->get_orders();
 
-            if ($location === strtolower(self::getShippingDetails($singleOrder)['Pickup Location']) && $date === $pickupDate) {
-                $order = new Order($singleOrder);
-                $orderId = $order->getOrderID();
+            $surnameArgs = [
+                'limit' => -1,
+                'billing_last_name' => $searchTerm,
+            ];
+            $surnameQuery = new \WC_Order_Query($surnameArgs);
+            $surnameOrders = $surnameQuery->get_orders();
 
-
-                if ($order->getOrderStatus() != "6" && $order->getOrderStatus() != "7") {
-
-                    if (!isset($orderData[$orderId])) {
-                        $orderData[$orderId] = [
-                            'order' => $order->newOrderData(),
-                            'orderItems' => []
-                        ];
-                    }
-
-                    $orderItems = [];
-                    foreach ($order->getOrderItems() as $itemKey => $item) {
-                        $newOrderItem = new OrderItem($item, $itemKey, $orderId);
-                        $orderItems[] = $newOrderItem->newOrderItemData();
-                    };
-
-                    $orderData[$orderId]['orderItems'] = $orderItems;
-                }
-            }
+            $orders = array_unique(array_merge($firstNameOrders, $surnameOrders), SORT_REGULAR);
         }
+
+        $orderData = self::searchOrderDataAsJson($orders);
+
         return $orderData;
     }
 
+    public static function checkPostcode($postcode)
+    {
+        $postcode = strtoupper(str_replace(' ', '', $postcode));
+        if (preg_match("/(^[A-Z]{1,2}[0-9R][0-9A-Z]?[\s]?[0-9][ABD-HJLNP-UW-Z]{2}$)/i", $postcode) || preg_match("/(^[A-Z]{1,2}[0-9R][0-9A-Z]$)/i", $postcode)) {
+            return true;
+        } else {
+            return false;
+        }
+    }
+
+    public static function searchOrderDataAsJson($orders)
+    {
+        $days = [];
+        foreach ($orders as $singleOrder) {
+
+            if ($_GET['location'] === strtolower(self::getShippingDetails($singleOrder)['Pickup Location'])) {
+                $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
+                $pickupDate = strtotime($pickupDate);
+                $newDate = date('l jS \of F', $pickupDate);
+
+                $order = new Order($singleOrder);
+
+                if (!isset($days[$pickupDate])) {
+                    $days[$pickupDate] = [
+                        'date' => $newDate,
+                        'orders' => [],
+                    ];
+                }
+                $days[$pickupDate]['orders'][] = $order->newOrderData();
+
+            }
+        }
+
+        return json_encode($days);
+    }
 
     public static function viewOrders($data)
     {
@@ -301,7 +337,7 @@ class OrderController
             $shopNumber = get_post_meta($orderNumber, 'shop_id');
             $finalPrice = get_post_meta($orderNumber, 'final_price');
             if (!$shopNumber || !$finalPrice) {
-                $successMessage = 'Order not Updated, please check you have input the shop number and/or final price';
+                $successMessage = 'Order not Updated, please check you have input the shop number and final price';
             } else {
                 $order->update_status('wc-ready');
                 self::emailCustomerOrder($shopNumber, $order);
@@ -312,8 +348,9 @@ class OrderController
             $shopNumber = get_post_meta($orderNumber, 'shop_id');
             $finalPrice = get_post_meta($orderNumber, 'final_price');
             if (!$shopNumber || !$finalPrice) {
-                $successMessage = 'Order not Updated, please check you have input the shop number and/or final price';
+                $successMessage = 'Order not Updated, please check you have input the shop number and final price';
             } else {
+                self::emailCustomerThankYou($order);
                 $order->update_status('wc-collected');
                 $successMessage = 'Order has been collected';
             }
@@ -322,6 +359,10 @@ class OrderController
             $order->update_status('wc-cancelled');
             $successMessage = 'This order has been marked as cancelled';
         }
+        if ($statusNumber == 8) {
+            $order->update_status('wc-notcollected');
+            $successMessage = 'This order has been marked as not collected';
+        }
 
         return $successMessage;
 
@@ -332,17 +373,62 @@ class OrderController
         $shipping = self::getShippingDetails($order);
         $order = new Order($order);
 
-        $to = 'jmumford@blue2.co.uk';
+        $finalPrice = $order->getFinalPrice();
+        $orderItems = [];
+
+        foreach ($order->getOrderItems() as $itemKey => $item) {
+            $newOrderItem = new OrderItem($item, $itemKey, $order->getOrderID());
+            $orderItems[] = $newOrderItem->newOrderItemData();
+        };
+
+        $to = $order->getEmail();
         $subject = 'Your Simon Howie Order is ready to collect at our ' . $shipping['Pickup Location'] . ' branch';
         $message = '
-            Dear ' . $order->getName() . '
-            Your order from Simon Howie is now ready to collect at ' . $shipping['Pickup Location'] . '
-            Your shop order number is ' . $shopNumber[0] . ' please quote this when collecting your order. 
+            Dear ' . $order->getName() . '<br>
+            Your order from Simon Howie is now ready to collect at ' . $shipping['Pickup Location'] . '<br>
+            Your shop order number is ' . $shopNumber[0] . ' please quote this when collecting your order.<br>
 
-            Best regards, The Simon Howie Team.
+            The final price for the order is: £' . $finalPrice . '';
+
+        $message .= '<table style="padding:25px 0;">';
+        $message .= '<thead style="font-weight:bold;">';
+        $message .= '<tr style="border-bottom:1px solid #000;">';
+        $message .= '<td style="font-weight:bold;">Product Title</td><td>Weight (g)</td><td>Unit Label</td><td>Units</td><td>Pack Size</td><td>Qty</td>';
+        $message .= '</tr>';
+        $message .= '</thead>';
+        $message .= '<tbody>';
+        foreach ($orderItems as $orderItem) {
+            $message .= '<tr>';
+            $message .= '<td>' . $orderItem['product_title'] . '</td><td>' . $orderItem['weight'] . '</td><td>' . $orderItem['unit_label'] . '</td><td>' . $orderItem['unit'] . '</td><td>' . $orderItem['size'] . '</td><td>' . $orderItem['qty'] . '</td>';
+            $message .= '</tr>';
+        };
+        $message .= '</tbody>';
+        $message .= '</table>';
+        $message .= 'Best regards, The Simon Howie Team.
+        ';
+        $headers = ['Content-Type: text/html; charset=UTF-8'];
+
+        wp_mail($to, $subject, $message, $headers);
+    }
+
+    public static function emailCustomerThankYou($order)
+    {
+
+        $order = new Order($order);
+
+        $to = $order->getEmail();
+        $subject = 'Thank you for collecting your Simon Howie Order';
+        $message = '
+        Dear ' . $order->getName() . '
+        
+        Thank you for collecting your order.
+        
         ';
 
-        wp_mail($to, $subject, $message);
+        $headers = ['Content-Type: text/html; charset=UTF-8'];
+
+        wp_mail($to, $subject, $message, $headers);
+
     }
 
     public static function registerNewOrderStatus()
@@ -387,7 +473,22 @@ class OrderController
             'show_in_admin_status_list' => true,
             'label_count' => _n_noop('Collected <span class="count">(%s)</span>', 'Collected <span class="count">(%s)</span>'),
         ]);
-
+        register_post_status('wc-notcollected', [
+            'label' => 'Not Collected',
+            'public' => true,
+            'exclude_from_search' => false,
+            'show_in_admin_all_list' => true,
+            'show_in_admin_status_list' => true,
+            'label_count' => _n_noop('Not Collected <span class="count">(%s)</span>', 'Not Collected <span class="count">(%s)</span>'),
+        ]);
+        register_post_status('wc-datechanged', [
+            'label' => 'Collection Date Changed',
+            'public' => true,
+            'exclude_from_search' => false,
+            'show_in_admin_all_list' => true,
+            'show_in_admin_status_list' => true,
+            'label_count' => _n_noop('Collection Date Changed <span class="count">(%s)</span>', 'Collection Date Changed <span class="count">(%s)</span>'),
+        ]);
     }
 
     public static function getNotes($data)
@@ -395,12 +496,12 @@ class OrderController
         global $wpdb;
 
         $orderNumber = $data->get_params()['id'];
+        $orderNotes = [];
 
-
-        $table_perfixed = $wpdb->prefix . 'comments';
+        $tablePrefixed = $wpdb->prefix . 'comments';
         $results = $wpdb->get_results("
             SELECT *
-            FROM $table_perfixed
+            FROM $tablePrefixed
             WHERE  `comment_post_ID` = $orderNumber
             AND  `comment_type` LIKE  'order_note'
         ");
@@ -439,6 +540,95 @@ class OrderController
         return $response;
     }
 
+    public static function getSingleOrderForPrint($orderId)
+    {
+        $order = wc_get_order($orderId);
+
+        $orderData = self::singleOrderDataForPrint($order);
+
+        return $orderData;
+    }
+
+    public static function singleOrderDataForPrint($order)
+    {
+        $orderData = [];
+
+        $order = new Order($order);
+        $orderId = $order->getOrderID();
+        if (!isset($orderData[$orderId])) {
+            $orderData[$orderId] = [
+                'order' => $order->newOrderData(),
+                'orderItems' => [],
+            ];
+        }
+        $orderItems = [];
+        foreach ($order->getOrderItems() as $itemKey => $item) {
+            $newOrderItem = new OrderItem($item, $itemKey, $orderId);
+            $orderItems[] = $newOrderItem->newOrderItemData();
+        };
+        $orderData[$orderId]['orderItems'] = $orderItems;
+        return $orderData;
+    }
+
+    public static function getAllOrdersForPrint($location, $date, $status)
+    {
+        $ordersForDate = date('Y-m-d', $date);
+
+        $orderData = [];
+        if (class_exists('WC_Order_Query')) {
+            $query = new \WC_Order_Query([
+                'limit' => -1,
+                'orderby' => 'date',
+                'order' => 'ASC',
+            ]);
+            $orders = $query->get_orders();
+
+            $orderData = self::orderDataForPrint($orders, $location, $ordersForDate, $status);
+        }
+        return $orderData;
+    }
+
+
+    public static function orderDataForPrint($orders, $location, $date, $status)
+    {
+
+        $orderData = [];
+        foreach ($orders as $singleOrder) {
+            $pickupDate = self::getShippingDetails($singleOrder)['Pickup Date'];
+
+            if ($location === strtolower(self::getShippingDetails($singleOrder)['Pickup Location']) && $date === $pickupDate) {
+                $order = new Order($singleOrder);
+                $orderId = $order->getOrderID();
+
+                if ($status === 'to-be-made') {
+                    $statuses = ['5', '6', '7', '8'];
+                } else {
+                    $statuses = ['6', '7', '8'];
+                }
+
+
+                if (!in_array($order->getOrderStatus(), $statuses)) {
+
+                    if (!isset($orderData[$orderId])) {
+                        $orderData[$orderId] = [
+                            'order' => $order->newOrderData(),
+                            'orderItems' => [],
+                        ];
+                    }
+
+                    $orderItems = [];
+                    foreach ($order->getOrderItems() as $itemKey => $item) {
+                        $newOrderItem = new OrderItem($item, $itemKey, $orderId);
+                        $orderItems[] = $newOrderItem->newOrderItemData();
+                    };
+
+                    $orderData[$orderId]['orderItems'] = $orderItems;
+                }
+            }
+        }
+        return $orderData;
+    }
+
     function dateSort($a, $b)
     {
         return strtotime($a) - strtotime($b);
@@ -455,29 +645,11 @@ class OrderController
                 $newOrderStatuses['wc-being-collated'] = 'Being collated';
                 $newOrderStatuses['wc-ready'] = 'Ready for collection';
                 $newOrderStatuses['wc-collected'] = 'Collected';
+                $newOrderStatuses['wc-notcollected'] = 'Not Collected';
+                $newOrderStatuses['wc-datechanged'] = 'Collection Date Changed';
             }
         }
         return $newOrderStatuses;
     }
 
-    public static function getAllOrdersForPrint($location, $date)
-    {
-        $ordersForDate = date('Y-m-d', $date);
-
-
-        $orderData = [];
-        if (class_exists('WC_Order_Query')) {
-            $query = new \WC_Order_Query([
-                'limit' => -1,
-                'orderby' => 'date',
-                'order' => 'ASC',
-            ]);
-            $orders = $query->get_orders();
-
-            $orderData = self::orderDataForPrint($orders, $location, $ordersForDate);
-        }
-        return $orderData;
-
-    }
-
 }
\ No newline at end of file
